==> cloudcomponents.cdk-blue-green-container-deployment-2.1.0.tar.gz: cloudcomponents.cdk-blue-green-container-deployment-2.1.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cloudcomponents.cdk-blue-green-container-deployment",
    "version": "2.1.0",
    "description": "Blue green container deployment with CodeDeploy",
    "license": "MIT",
    "url": "https://github.com/cloudcomponents/cdk-constructs",
    "long_description_content_type": "text/markdown",
    "author": "hupe1980",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/cloudcomponents/cdk-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cloudcomponents.cdk_blue_green_container_deployment",
        "cloudcomponents.cdk_blue_green_container_deployment._jsii"
    ],
    "package_data": {
        "cloudcomponents.cdk_blue_green_container_deployment._jsii": [
            "cdk-blue-green-container-deployment@2.1.0.jsii.tgz"
        ],
        "cloudcomponents.cdk_blue_green_container_deployment": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk-lib>=2.8.0, <3.0.0",
        "constructs>=10.0.41, <11.0.0",
        "jsii>=1.52.1, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> cloudcomponents.cdk-blue-green-container-deployment-2.2.0.tar.gz: cloudcomponents.cdk-blue-green-container-deployment-2.2.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cloudcomponents.cdk-blue-green-container-deployment",
    "version": "2.2.0",
    "description": "Blue green container deployment with CodeDeploy",
    "license": "MIT",
    "url": "https://github.com/cloudcomponents/cdk-constructs",
    "long_description_content_type": "text/markdown",
    "author": "hupe1980",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/cloudcomponents/cdk-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cloudcomponents.cdk_blue_green_container_deployment",
        "cloudcomponents.cdk_blue_green_container_deployment._jsii"
    ],
    "package_data": {
        "cloudcomponents.cdk_blue_green_container_deployment._jsii": [
            "cdk-blue-green-container-deployment@2.2.0.jsii.tgz"
        ],
        "cloudcomponents.cdk_blue_green_container_deployment": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.28.0, <3.0.0",
        "constructs>=10.0.41, <11.0.0",
        "jsii>=1.95.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
